bowser home # fdisk -l /dev/sda
Disk /dev/sda: 203.9 GB, 203928109056 bytes
255 heads, 63 sectors/track, 24792 cylinders
Units = cylinders of 16065 * 512 = 8225280 bytes
Disk identifier: 0x06580657
Device Boot Start End Blocks Id System
/dev/sda1 * 1 17 136521 fd Linux raid autodetect
/dev/sda2 18 24318 195197782+ fd Linux raid autodetect
bowser home # fdisk -l /dev/sdb
Disk /dev/sdb: 300.0 GB, 300069052416 bytes
255 heads, 63 sectors/track, 36481 cylinders
Units = cylinders of 16065 * 512 = 8225280 bytes
Disk identifier: 0x00000001
Device Boot Start End Blocks Id System
/dev/sdb1 * 1 17 136521 83 Linux
/dev/sdb2 18 261 1959930 82 Linux swap / Solaris
/dev/sdb3 262 12159 95570685 83 Linux
/dev/sdb4 12160 36460 195197782+ fd Linux raid autodetect
bowser home # fdisk -l /dev/sdc
Disk /dev/sdc: 200.0 GB, 200049647616 bytes
255 heads, 63 sectors/track, 24321 cylinders
Units = cylinders of 16065 * 512 = 8225280 bytes
Disk identifier: 0x62c79e19
Device Boot Start End Blocks Id System
/dev/sdc1 * 1 17 136521 fd Linux raid autodetect
/dev/sdc2 18 24318 195197782+ fd Linux raid autodetect
bowser home # fdisk -l /dev/sdd
Disk /dev/sdd: 200.0 GB, 200049647616 bytes
255 heads, 63 sectors/track, 24321 cylinders
Units = cylinders of 16065 * 512 = 8225280 bytes
Disk identifier: 0x62c79e1a
Device Boot Start End Blocks Id System
/dev/sdd1 * 1 17 136521 fd Linux raid autodetect
/dev/sdd2 18 24318 195197782+ fd Linux raid autodetect
bowser home # mdadm --create /dev/md2 --level=5 --raid-devices=4 /dev/sda2 /dev/sdb4 /dev/sdc2 /dev/sdd2
mdadm: /dev/sda2 appears to contain an ext2fs file system
size=197623168K mtime=Tue Dec 4 02:27:37 2007
mdadm: /dev/sda2 appears to be part of a raid array:
level=raid1 devices=4 ctime=Tue Dec 4 02:30:14 2007
mdadm: /dev/sdb4 appears to contain an ext2fs file system
size=197623168K mtime=Tue Dec 4 02:27:37 2007
mdadm: /dev/sdb4 appears to be part of a raid array:
level=raid1 devices=4 ctime=Tue Dec 4 02:30:14 2007
mdadm: /dev/sdc2 appears to contain an ext2fs file system
size=197623168K mtime=Tue Dec 4 02:27:37 2007
mdadm: /dev/sdc2 appears to be part of a raid array:
level=raid1 devices=4 ctime=Tue Dec 4 02:30:14 2007
mdadm: /dev/sdd2 appears to contain an ext2fs file system
size=197623168K mtime=Tue Dec 4 02:27:37 2007
mdadm: /dev/sdd2 appears to be part of a raid array:
level=raid1 devices=4 ctime=Tue Dec 4 02:30:14 2007
mdadm: largest drive (/dev/sdb4) exceed size (754944K) by more than 1%
Continue creating array? y
mdadm: array /dev/md2 started.
bowser home # cat /proc/mdstat
Personalities : [linear] [raid0] [raid1] [raid6] [raid5] [raid4] [multipath]
md1 : active raid1 sdd1[2] sdc1[1] sda1[0]
136448 blocks [3/3] [UUU]
md2 : active raid5 sdd2[3] sdc2[2] sdb4[1] sda2[0]
2264832 blocks level 5, 64k chunk, algorithm 2 [4/4] [UUUU]
unused devices: <none>